@@ -1,7 +1,7 @@
 #ifndef __GDICT_APP_H_
 #define __GDICT_APP_H_
 
-/* $Id: gdict-app.h,v 1.6 2000/04/06 00:46:16 hovinen Exp $ */
+/* $Id: gdict-app.h,v 1.8 2000/05/19 00:18:59 hovinen Exp $ */
 
 /*
  *  Mike Hughes <mfh@psilord.com>
@@ -39,9 +39,12 @@ extern GnomePrinter *gdict_printer;
 extern dict_context_t *context;
 
 gint gdict_init_context (void);
+void gdict_open_speller (void);
+gint gdict_spell (gchar *text, gboolean pattern);
 void gdict_app_clear (void);
 void gdict_app_do_lookup (gchar *text);
 void gdict_app_show_preferences (void);
+void gdict_not_online (void);
 GtkWidget *gdict_app_create (void);
 
 #endif /* __GDICT_APP_H_ */
