@@ -17,6 +17,7 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
  * USA
  */
+
 #include "config.h"
 
 #include <gnome.h>
@@ -35,7 +36,6 @@
 #include <linux/fs.h>
 #endif
 
-
 #include "gfloppy.h"
 #include "fdformat.h"
 #include "badblocks.h"
@@ -64,8 +64,7 @@ floppy_block_size (GFloppySize size)
 		break;
 	case 2:
 		/* 720k */
-		rc = 1440;
-		break;
+		rc = 1440;		break;
 	case 3:
 		/* 360k */
 		rc = 720;
@@ -143,7 +142,6 @@ make_mke2fs_cmd (GFloppy *floppy)
 	}
 	return retval;
 #endif
-
 }
 
 static int
@@ -259,5 +257,3 @@ test_floppy_device (gchar *device)
 	/* all ok */
 	return 0;
 }
-
-
