@@ -25,10 +25,10 @@
 #include <stdio.h>
 
 
-static int log_write(time_t t, char *s)
+static int log_write(time_t t, const char *s)
 {
 	FILE *f;
-	char date[20];
+	char date[256];
 	char *filename;
 
 	if (!config_logfile_name) return 1;
@@ -42,9 +42,14 @@ static int log_write(time_t t, char *s)
 	} else {
 		f = fopen(config_logfile_name, "at");
 	}
-	g_return_val_if_fail(f != NULL, 0);
+	if (f == NULL) {
+		g_warning (_("Cannot open logfile %s for append"),
+			   config_logfile_name);
+		return 0;
+	}
 	if (t == -1) t = time(NULL);
-	strftime(date, 20, "%b %d %H:%M:%S", localtime(&t));
+	if (strftime(date, sizeof (date), "%b %d %H:%M:%S", localtime(&t)) <= 0)
+		strcpy (date, "???");
 	fprintf(f, "%s %s\n", date, s);
 	fclose(f);
 	return 1;
@@ -52,11 +57,12 @@ static int log_write(time_t t, char *s)
 
 
 static char *
-build_log_entry(char *format, project *proj)
+build_log_entry(const char *format, project *proj)
 {
 	GString *str;
 	char tmp[256];
-	char *p;
+	const char *p;
+	char *ret;
 
 	if (!format)
 		format = config_logfile_str;
@@ -64,7 +70,7 @@ build_log_entry(char *format, project *proj)
 		return g_strdup(_("program started"));
 	if ((!format) || (!format[0]))
 		return g_strdup(proj->title);
-	str = g_string_new(NULL);
+	str = g_string_new (NULL);
 	for (p = format; *p; p++) {
 		if (*p != '%') {
 			g_string_append_c(str, *p);
@@ -82,34 +88,40 @@ build_log_entry(char *format, project *proj)
 							_("no description"));
 				break;
 			case 'T':
-				sprintf(tmp, "%d:%02d:%02d", proj->secs / 3600,
-					(proj->secs / 60) % 60,
-					proj->secs % 60);
+				g_snprintf(tmp, sizeof (tmp),
+					   "%d:%02d:%02d", proj->secs / 3600,
+					   (proj->secs / 60) % 60,
+					   proj->secs % 60);
 				g_string_append(str, tmp);
 				break;
 			case 'm':
-				sprintf(tmp, "%d", proj->day_secs / 60);
+				g_snprintf(tmp, sizeof (tmp),
+					   "%d", proj->day_secs / 60);
 				g_string_append(str, tmp);
 				break;
 			case 'M':
-				sprintf(tmp, "%02d",
-					(proj->day_secs / 60) % 60);
+				g_snprintf(tmp, sizeof (tmp), "%02d",
+					   (proj->day_secs / 60) % 60);
 				g_string_append(str, tmp);
 				break;
 			case 's':
-				sprintf(tmp, "%d", proj->day_secs);
+				g_snprintf(tmp, sizeof (tmp),
+					   "%d", proj->day_secs);
 				g_string_append(str, tmp);
 				break;
 			case 'S':
-				sprintf(tmp, "%02d", proj->day_secs % 60);
+				g_snprintf(tmp, sizeof (tmp),
+					   "%02d", proj->day_secs % 60);
 				g_string_append(str, tmp);
 				break;
 			case 'h':
-				sprintf(tmp, "%d", proj->day_secs / 3600);
+				g_snprintf(tmp, sizeof (tmp),
+					   "%d", proj->day_secs / 3600);
 				g_string_append(str, tmp);
 				break;
 			case 'H':
-				sprintf(tmp, "%02d", proj->day_secs / 3600);
+				g_snprintf(tmp, sizeof (tmp),
+					   "%02d", proj->day_secs / 3600);
 				g_string_append(str, tmp);
 				break;
 			default:
@@ -118,9 +130,9 @@ build_log_entry(char *format, project *proj)
 			}
 		}
 	}
-	p = str->str;
-	g_string_free(str, 0);
-	return p;
+	ret = str->str;
+	g_string_free (str, FALSE);
+	return ret;
 }
 
 
