@@ -35,6 +35,10 @@ static GnomeUIInfo menu_main_file[] = {
 		save_project_list, NULL, NULL,
 		GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_SAVE,
 		'S', GDK_CONTROL_MASK, NULL},
+	{GNOME_APP_UI_ITEM, N_("_Export Current State"), NULL,
+		export_current_state, NULL, NULL,
+		GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_SAVE,
+		'E', GDK_CONTROL_MASK, NULL},
 	GNOMEUIINFO_SEPARATOR,
 	GNOMEUIINFO_MENU_EXIT_ITEM(quit_app,NULL),
 	GNOMEUIINFO_END
@@ -128,7 +132,6 @@ GtkWidget *
 menus_get_popup(void)
 {
 	static GtkWidget *menu = NULL;
-	GnomeUIInfo *p;
 
 	if (menu) return menu;
 
@@ -161,12 +164,16 @@ menu_set_states(void)
 	GtkCheckMenuItem *mi;
 
 	if (!menu_main_timer[MENU_TIMER_START_POS].widget) return;
+	gtk_widget_set_sensitive(menu_main_timer[MENU_TIMER_TOGGLE_POS].widget,
+				 1);
 	mi = GTK_CHECK_MENU_ITEM(menu_main_timer[MENU_TIMER_TOGGLE_POS].widget);
 	mi->active = (main_timer != 0);
+	gtk_widget_set_sensitive(menu_main_timer[MENU_TIMER_TOGGLE_POS].widget,
+				 (cur_proj != NULL));
 	gtk_widget_set_sensitive(menu_main_timer[MENU_TIMER_START_POS].widget,
-				 (main_timer == 0));
+				 (main_timer == 0) && (cur_proj));
 	gtk_widget_set_sensitive(menu_main_timer[MENU_TIMER_STOP_POS].widget,
-				 (main_timer != 0));
+				 (main_timer != 0) && (cur_proj));
 	gtk_widget_set_sensitive(menu_main_edit[MENU_EDIT_CUT_POS].widget,
 				 (cur_proj) ? 1 : 0);
 	gtk_widget_set_sensitive(menu_main_edit[MENU_EDIT_COPY_POS].widget,
