@@ -41,7 +41,7 @@ project *project_new(void)
 {
 	project *proj;
 	
-	proj = g_malloc(sizeof(project));
+	proj = g_new0(project, 1);
 	proj->title = NULL;
 	proj->desc = NULL;
 	proj->secs = proj->day_secs = 0;
@@ -50,16 +50,14 @@ project *project_new(void)
 }
 
 
-project *project_new_title_desc(char *t, char *d)
+project *project_new_title_desc(const char *t, const char *d)
 {
 	project *proj;
 
 	proj = project_new();
 	if (!t || !d) return proj;
-	proj->title = g_malloc(strlen(t) + 1);
-	strcpy(proj->title, t);
-        proj->desc = g_malloc(strlen(d) + 1);
-        strcpy(proj->desc, d);
+	proj->title = g_strdup (t);
+        proj->desc = g_strdup (d);
 	return proj;
 }
 
@@ -90,14 +88,16 @@ void project_destroy(project *proj)
 {
 	if (!proj) return;
 	project_list_remove(proj);
-	if (proj->title) g_free(proj->title);
-	if (proj->desc) g_free(proj->desc);
+	g_free(proj->title);
+	proj->title = NULL;
+	g_free(proj->desc);
+	proj->desc = NULL;
 	g_free(proj);
 }
 
 
 
-void project_set_title(project *proj, char *t)
+void project_set_title(project *proj, const char *t)
 {
 	if (!proj) return;
 	if (proj->title) g_free(proj->title);
@@ -112,7 +112,7 @@ void project_set_title(project *proj, char *t)
 
 
 
-void project_set_desc(project *proj, char *d)
+void project_set_desc(project *proj, const char *d)
 {
 	if (!proj) return;
 	if (proj->desc) g_free(proj->desc);
@@ -223,16 +223,15 @@ void project_list_time_reset(void)
 
 
 
-static char *build_rc_name(void)
+static const char *build_rc_name(void)
 {
-	static char buf[1024] = { 0 };
+	static char *buf = NULL;
 
-	if (buf[0]) return buf;
-	if (getenv("HOME")) {
-		strcpy(buf, getenv("HOME"));
-		strcat(buf, "/" RC_NAME);
+	if (buf != NULL) return buf;
+	if (g_getenv("HOME") != NULL) {
+		buf = g_concat_dir_and_file (g_getenv ("HOME"), RC_NAME);
 	} else {
-		strcpy(buf, RC_NAME);
+		buf = g_strdup (RC_NAME);
 	}
 	return buf;
 }
@@ -264,9 +263,10 @@ read_tb_sects(char *s)
 
 
 static int
-project_list_load_old(char *fname)
+project_list_load_old(const char *fname)
 {
 	FILE *f;
+	const char *realname;
 	project_list *pl, *t;
 	project *proj = NULL;
 	char s[1024];
@@ -274,12 +274,15 @@ project_list_load_old(char *fname)
 	time_t tmp_time = -1;
         int _n, _f, _c, _p, _t, _o, _h, _e;
 
-	if (!fname) fname = build_rc_name();
-	if (NULL == (f = fopen(fname, "rt"))) {
+	if (fname != NULL)
+		realname = fname;
+	else
+		realname = build_rc_name();
+	if (NULL == (f = fopen(realname, "rt"))) {
 #ifdef ENOENT
                 if (errno == ENOENT) return 0;
 #endif
-		g_warning("could not open %s\n", fname);
+		g_warning("could not open %s\n", realname);
 		return 0;
 	}
 	pl = plist;
@@ -401,7 +404,7 @@ project_list_load_old(char *fname)
 
 	err:
 	fclose(f);
-	g_warning("error reading %s\n", fname);
+	g_warning("error reading %s\n", realname);
 	project_list_destroy();
 	plist = pl;
 	return 0;
@@ -410,9 +413,9 @@ project_list_load_old(char *fname)
 
 
 int
-project_list_load(char *fname)
+project_list_load(const char *fname)
 {
-        char s[64];
+        char s[256];
         int i, num;
         project *proj;
         int _n, _f, _c, _p, _t, _o, _h, _e;
@@ -470,7 +473,7 @@ project_list_load(char *fname)
 	else
 		gtk_widget_hide(status_bar);
 	for (i = 0; i < GTK_CLIST(glist)->columns; i++) {
-		sprintf(s, GTT"CList/ColumnWidth%d=0", i);
+		g_snprintf(s, sizeof (s), GTT"CList/ColumnWidth%d=0", i);
 		num = gnome_config_get_int(s);
 		if (num) {
 			clist_header_width_set = 1;
@@ -482,7 +485,7 @@ project_list_load(char *fname)
         for (i = 0; i < num; i++) {
                 proj = project_new();
                 project_list_add(proj);
-                sprintf(s, GTT"Project%d/Title", i);
+                g_snprintf(s, sizeof (s), GTT"Project%d/Title", i);
                 project_set_title(proj, gnome_config_get_string(s));
 		if ((proj->title) && (first_proj_title)) {
 			if (0 == strcmp(proj->title, first_proj_title)) {
@@ -490,11 +493,11 @@ project_list_load(char *fname)
 				first_proj_title = NULL;
 			}
 		}
-                sprintf(s, GTT"Project%d/Desc", i);
+                g_snprintf(s, sizeof (s), GTT"Project%d/Desc", i);
                 project_set_desc(proj, gnome_config_get_string(s));
-                sprintf(s, GTT"Project%d/SecsEver=0", i);
+                g_snprintf(s, sizeof (s), GTT"Project%d/SecsEver=0", i);
                 proj->secs = gnome_config_get_int(s);
-                sprintf(s, GTT"Project%d/SecsDay=0", i);
+                g_snprintf(s, sizeof (s), GTT"Project%d/SecsDay=0", i);
                 proj->day_secs = gnome_config_get_int(s);
         }
 	first_proj_title = NULL;
@@ -515,14 +518,14 @@ project_list_load(char *fname)
 
 
 int
-project_list_save(char *fname)
+project_list_save(const char *fname)
 {
         char s[64];
         project_list *pl;
         int i, old_num;
 
         old_num = gnome_config_get_int(GTT"Misc/NumProjects=0");
-        sprintf(s, "%ld", last_timer);
+        g_snprintf(s, sizeof (s), "%ld", last_timer);
         gnome_config_set_string(GTT"Misc/LastTimer", s);
         gnome_config_set_int(GTT"Misc/TimerRunning", (main_timer != 0));
         gnome_config_set_bool(GTT"Display/ShowSecs", config_show_secs);
@@ -563,36 +566,83 @@ project_list_save(char *fname)
 		gnome_config_set_string(GTT"LogFile/EntryStop", "");
         gnome_config_set_int(GTT"LogFile/MinSecs", config_logfile_min_secs);
 	for (i = 0; i < GTK_CLIST(glist)->columns; i++) {
-		sprintf(s, GTT"CList/ColumnWidth%d", i);
+		g_snprintf(s, sizeof (s), GTT"CList/ColumnWidth%d", i);
 		gnome_config_set_int(s, GTK_CLIST(glist)->column[i].width);
 	}
         i = 0;
         for (pl = plist; pl; pl = pl->next) {
                 if (!pl->proj) continue;
                 if (!pl->proj->title) continue;
-                sprintf(s, GTT"Project%d/Title", i);
+                g_snprintf(s, sizeof (s), GTT"Project%d/Title", i);
                 gnome_config_set_string(s, pl->proj->title);
-                sprintf(s, GTT"Project%d/Desc", i);
+                g_snprintf(s, sizeof (s), GTT"Project%d/Desc", i);
                 if (pl->proj->desc) {
                         gnome_config_set_string(s, pl->proj->desc);
                 } else {
                         gnome_config_clean_key(s);
                 }
-                sprintf(s, GTT"Project%d/SecsEver", i);
+                g_snprintf(s, sizeof (s), GTT"Project%d/SecsEver", i);
                 gnome_config_set_int(s, pl->proj->secs);
-                sprintf(s, GTT"Project%d/SecsDay", i);
+                g_snprintf(s, sizeof (s), GTT"Project%d/SecsDay", i);
                 gnome_config_set_int(s, pl->proj->day_secs);
                 i++;
         }
         gnome_config_set_int(GTT"Misc/NumProjects", i);
         for (; i < old_num; i++) {
-                sprintf(s, GTT"Project%d", i);
+                g_snprintf(s, sizeof (s), GTT"Project%d", i);
                 gnome_config_clean_section(s);
         }
         gnome_config_sync();
         return 1;
 }
 
+static char *
+get_time (int secs)
+{
+	/* Translators: This is a "time format", that is
+	 * format on how to print the elapsed time with
+	 * hours:minutes:seconds. */
+	return g_strdup_printf (_("%d:%02d:%02d"),
+				secs / (60*60),
+				(secs / 60) % 60,
+				secs % 60);
+}
+
+gboolean
+project_list_export (const char *fname)
+{
+	FILE *fp;
+        project_list *pl;
+
+	fp = fopen (fname, "w");
+	if (fp == NULL)
+		return FALSE;
+
+	/* Translators: this is the header of a table separated file,
+	 * it should really be all ASCII, or at least not multibyte,
+	 * I don't think most spreadsheets would handle that well. */
+	fprintf (fp, "Title\tDescription\tTotal time\tTime today\n");
+
+        for (pl = plist; pl; pl = pl->next) {
+		char *total_time, *time_today;
+                if (!pl->proj) continue;
+                if (!pl->proj->title) continue;
+		total_time = get_time (pl->proj->secs);
+		time_today = get_time (pl->proj->day_secs);
+		fprintf (fp, "%s\t%s\t%s\t%s\n",
+			 gtt_sure_string (pl->proj->title),
+			 gtt_sure_string (pl->proj->desc),
+			 total_time,
+			 time_today);
+		g_free (total_time);
+		g_free (time_today);
+        }
+
+	fclose (fp);
+
+        return TRUE;
+}
+
 
 
 char *project_get_timestr(project *proj, int show_secs)
@@ -610,18 +660,21 @@ char *project_get_timestr(project *proj, int show_secs)
 	}
 	if (t >= 0) {
 		if (show_secs)
-			sprintf(s, "%02d:%02d:%02d", (int)(t / 3600),
-				(int)((t % 3600) / 60), (int)(t % 60));
+			g_snprintf(s, sizeof (s),
+				   "%02d:%02d:%02d", (int)(t / 3600),
+				   (int)((t % 3600) / 60), (int)(t % 60));
 		else
-			sprintf(s, "%02d:%02d", (int)(t / 3600),
-				(int)((t % 3600) / 60));
+			g_snprintf(s, sizeof (s), "%02d:%02d", (int)(t / 3600),
+				   (int)((t % 3600) / 60));
 	} else {
 		if (show_secs)
-			sprintf(s, "-%02d:%02d:%02d", (int)(-t / 3600),
-				(int)((-t % 3600) / 60), (int)(-t % 60));
+			g_snprintf(s, sizeof (s),
+				   "-%02d:%02d:%02d", (int)(-t / 3600),
+				   (int)((-t % 3600) / 60), (int)(-t % 60));
 		else
-			sprintf(s, "-%02d:%02d", (int)(-t / 3600),
-				(int)((-t % 3600) / 60));
+			g_snprintf(s, sizeof (s),
+				   "-%02d:%02d", (int)(-t / 3600),
+				   (int)((-t % 3600) / 60));
 	}
 	return s;
 }
@@ -637,11 +690,11 @@ char *project_get_total_timestr(project *proj, int show_secs)
 		t = proj->secs;
 	}
 	if (show_secs)
-		sprintf(s, "%02d:%02d:%02d", (int)(t / 3600),
-			(int)((t % 3600) / 60), (int)(t % 60));
+		g_snprintf(s, sizeof (s), "%02d:%02d:%02d", (int)(t / 3600),
+			   (int)((t % 3600) / 60), (int)(t % 60));
 	else
-		sprintf(s, "%02d:%02d", (int)(t / 3600),
-			(int)((t % 3600) / 60));
+		g_snprintf(s, sizeof (s), "%02d:%02d", (int)(t / 3600),
+			   (int)((t % 3600) / 60));
 	return s;
 }
 
