@@ -147,9 +147,8 @@ chart_rescale_by_table(ChartDatum *datum, gdouble *table, gint nels, gint step)
     {
       datum->adj->upper = table[r->top_index];
       #ifdef DEBUG
-      printf("changed: %p=%2dx%d, %.0g..%.0g; %g..%g; %g(%d) -> %g(%d)\n",
-	datum, changed, step,
-	datum->top_min, datum->top_max, datum->min, datum->max, 
+      printf("changed: %p=%2dx%d, %g..%g; %g(%d) -> %g(%d)\n",
+	datum, changed, step, datum->min, datum->max, 
 	table[j], j, table[r->top_index], r->top_index);
       #endif
     }
@@ -303,13 +302,16 @@ chart_parameter_add(Chart *chart,
   datum->range_data = NULL;
   datum->active = TRUE;
   datum->idle = datum->newest = datum->history_count = 0;
+
   if (adj == NULL)
     adj = GTK_ADJUSTMENT(gtk_adjustment_new(0,0,0,0,0,0));
   datum->adj = adj;
-  datum->adj->upper = datum->top_min = 1.0;
-  datum->top_max = G_MAXDOUBLE;
-  datum->adj->lower = datum->bot_max = 0.0;
-  datum->top_min = G_MINDOUBLE;
+  datum->adj->upper = 1.0;
+  datum->adj->lower = 0.0;
+
+  datum->top_max = datum->bot_max = +G_MAXDOUBLE;
+  datum->top_min = datum->bot_min = -G_MAXDOUBLE;
+
   datum->colors = 0;
   datum->color_names = g_strdup(color_names);
   datum->gdk_gc = NULL;
@@ -420,7 +422,12 @@ val2gdk(gdouble val, GtkAdjustment *adj, gint height, ChartScaleStyle scale)
   else
     y = height - height * (val - adj->lower) / delta;
 
-  if (y < 0) y = 0; else if (height < y) y = height;
+  if (isnan(y))
+    y = height;
+  else if (y < 0)
+    y = 0;
+  else if (height < y)
+    y = height;
 
   return y + 0.5;
 }
